@@ -10,9 +10,6 @@ class show:
             self.error = 25001
         else:
             self.message = message
-        if not title:
-            pass
-        else:
             self.title = title
     
     def show(self):
@@ -22,7 +19,7 @@ class show:
             return self.error
         else:
             main = tkinter.Tk()
-            if not self.title == None:
+            if self.title:
                 main.title(self.title)
             else:
                 pass
